@@ -25,7 +25,14 @@ class interface:
         """
         self._pub_committer = None
 
-    def assimilate_api(api_list, func, cmd_group=None, cli_args=None, url_args=None):
+    def assimilate_api(
+        api_list,
+        func,
+        cmd_group=None,
+        cli_args=None,
+        url_args=None,
+        allowed_methods=None,
+    ):
         cmd_group = func.__name__.split("_") if cmd_group is None else cmd_group
         api_list.append(
             {
@@ -35,30 +42,46 @@ class interface:
                 "groups": cmd_group,
                 "cli_args": cli_args if cli_args is not None else [],
                 "url_args": url_args if url_args is not None else [],
+                "allowed_methods": allowed_methods,
             }
         )
         return func
 
-    def public_api(cmd_group=None, cli_args=None, url_args=None):
+    def public_api(cmd_group=None, cli_args=None, url_args=None, allowed_methods=None):
         def decorator_func(func):
             return interface.assimilate_api(
-                interface._public_api, func, cmd_group, cli_args, url_args
+                interface._public_api,
+                func,
+                cmd_group,
+                cli_args,
+                url_args,
+                allowed_methods,
             )
 
         return decorator_func
 
-    def private_api(cmd_group=None, cli_args=None, url_args=None):
+    def private_api(cmd_group=None, cli_args=None, url_args=None, allowed_methods=None):
         def decorator_func(func):
             return interface.assimilate_api(
-                interface._private_api, func, cmd_group, cli_args, url_args
+                interface._private_api,
+                func,
+                cmd_group,
+                cli_args,
+                url_args,
+                allowed_methods,
             )
 
         return decorator_func
 
-    def admin_api(cmd_group=None, cli_args=None, url_args=None):
+    def admin_api(cmd_group=None, cli_args=None, url_args=None, allowed_methods=None):
         def decorator_func(func):
             return interface.assimilate_api(
-                interface._admin_api, func, cmd_group, cli_args, url_args
+                interface._admin_api,
+                func,
+                cmd_group,
+                cli_args,
+                url_args,
+                allowed_methods,
             )
 
         return decorator_func
@@ -116,10 +139,16 @@ class interface:
             api_name is the name of the api being mapped to
         """
         param_map = {}
-        if api_name.startswith("master_active"):
+        if (
+            api_name.startswith("master_active")
+            or api_name.startswith("master_become")
+            or api_name.startswith("master_unbecome")
+        ):
             _caller = self
+        elif self.caller:
+            _caller = self._h.get_obj(self._m_id, uuid.UUID(self.caller))
         else:
-            _caller = self._caller
+            _caller = self
         if not hasattr(_caller, api_name):
             return self.interface_error(f"{api_name} not a valid API")
         func_sig = signature(getattr(_caller, api_name))
@@ -173,7 +202,6 @@ class interface:
         param_map = {}
         if not hasattr(self, api_name):
             return self.interface_error(f"{api_name} not a valid API")
-            return False
         func_sig = signature(getattr(self, api_name))
         for i in func_sig.parameters.keys():
             if i == "self":
@@ -195,7 +223,6 @@ class interface:
                     param_map[i] = val
                 else:
                     return self.interface_error(f"{type(val)} is not {p_type}")
-                    param_map[i] = None
             else:  # TODO: Can do type checks here too
                 param_map[i] = val
 
